@@ -11,15 +11,11 @@ use 5.008;
 
 Text::Hyphen::RU - determine positions for hyphens inside russian words
 
-=head1 VERSION
-
-Version 0.11
-
 =cut
 
 use base 'Text::Hyphen';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 SYNOPSIS
 
@@ -512,13 +508,18 @@ Donald Knuth and Frank Liang for the algorithm.
 
 Alexander Lebedev for all his valuable work on russian ispell
 dictionaries and russian hyphenation patterns. See his archive
-at L<ftp://scon155.phys.msu.ru/pub/russian/>.
+at L<ftp://scon155.phys.msu.ru/pub/russian/> or his hyphenation page
+at L<http://scon155.phys.msu.su/~swan/hyphenation.html>.
+
+These patterns are also a part of ruhyphen CTAN package which
+is available at L<https://www.ctan.org/tex-archive/language/hyphenation/ruhyphen>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Alex Kapranoff.
+Copyright 2008-2015 Alex Kapranoff.
 
-This program is released under the following license: BSD.
+This is free software; you can redistribute it and/or modify it under
+the terms GNU General Public License version 3.
 
 =cut
 
